#!/bin/bash

set -e -x

ls -la

# import maven settings file from the ENV
# Jenkins will pass a file that configure Maven to use internal mirror
mkdir -p ~/.m2

if test -f "maven_settings.xml"; then
  cp maven_settings.xml ~/.m2/settings.xml
fi

# add JAVA_HOME to jdk11 for pulsar-2.10
if [[ $PULSAR_VERSION == "2.10."* ]]; then
  export JAVA_HOME=/usr/lib/jvm/java-11-openjdk
fi

mvn -v

# Install necessary packages

# Build first without tests
mvn -B clean install -DskipTests -Dlicense.skip=true -Dmaven.javadoc.skip=true -Dspotbugs.skip -Dcheckstyle.skip \
    -nsu -q -Dorg.slf4j.simpleLogger.log.org.apache.maven.cli.transfer.Slf4jMavenTransferListener=warn
# skip the tests
#  mvn test

# Build the Docker images
cd docker 
mvn package -Pdocker,git-commit-id-no-git,-main -DUBUNTU_MIRROR="${UBUNTU_MIRROR:-http://archive.ubuntu.com/ubuntu/}" \
            -DUBUNTU_SECURITY_MIRROR="${UBUNTU_SECURITY_MIRROR:-http://security.ubuntu.com/ubuntu/}" \
            -Dorg.slf4j.simpleLogger.log.org.apache.maven.cli.transfer.Slf4jMavenTransferListener=warn
# Ensure that files are readable from non root user after the build
chmod -R -c a+r *

